pub struct AccountPowerCreep { /* private fields */ }Expand description
A PowerCreep unit that may or may not be spawned in the current
shard of the game world.
Implementations
Sourceimpl AccountPowerCreep
impl AccountPowerCreep
Sourcepub fn class(&self) -> PowerCreepClass
pub fn class(&self) -> PowerCreepClass
Retrieve this power creep’s PowerCreepClass.
Sourcepub fn delete_time(&self) -> Option<f64>
pub fn delete_time(&self) -> Option<f64>
The timestamp, in milliseconds since epoch, when the PowerCreep will
be permanently deleted due to AccountPowerCreep::delete. Can be
cancelled with the same function until then.
Sourcepub fn level(&self) -> u32
pub fn level(&self) -> u32
Current level of the power creep, which can be increased with
AccountPowerCreep::upgrade if you have unspent GPL.
Sourcepub fn name_jsstring(&self) -> JsString
pub fn name_jsstring(&self) -> JsString
The power creep’s name as a JsString.
Sourcepub fn powers(&self) -> JsHashMap<PowerType, PowerInfo>
pub fn powers(&self) -> JsHashMap<PowerType, PowerInfo>
The levels of this power creep’s abilities, with PowerType keys and
values containing power level and cooldown.
Sourcepub fn shard(&self) -> Option<JsString>
pub fn shard(&self) -> Option<JsString>
The shard the power creep is currently spawned on, if spawned.
Sourcepub fn spawn_cooldown_time(&self) -> Option<f64>
pub fn spawn_cooldown_time(&self) -> Option<f64>
The timestamp, in milliseconds since epoch, when the power creep will be allowed to spawn again after dying.
Sourcepub fn delete(&self, cancel: bool) -> Result<(), DeleteErrorCode>
pub fn delete(&self, cancel: bool) -> Result<(), DeleteErrorCode>
Set a power creep that is not currently spawned to be deleted. Can be
cancelled with true for the cancel paramater.
Sourcepub fn rename(&self, name: &JsString) -> Result<(), RenameErrorCode>
pub fn rename(&self, name: &JsString) -> Result<(), RenameErrorCode>
Change the name of the power creep. Must not be spawned.
Sourcepub fn spawn(&self, target: &StructurePowerSpawn) -> Result<(), SpawnErrorCode>
pub fn spawn(&self, target: &StructurePowerSpawn) -> Result<(), SpawnErrorCode>
Spawn the power creep at a StructurePowerSpawn.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn as_f64(&self) -> Option<f64>
pub fn as_f64(&self) -> Option<f64>
Returns the f64 value of this JS value if it’s an instance of a
number.
If this JS value is not an instance of a number then this returns
None.
Sourcepub fn as_string(&self) -> Option<String>
pub fn as_string(&self) -> Option<String>
If this JS value is a string value, this function copies the JS string
value into Wasm linear memory, encoded as UTF-8, and returns it as a
Rust String.
To avoid the copying and re-encoding, consider the
JsString::try_from() function from js-sys
instead.
If this JS value is not an instance of a string or if it’s not valid
utf-8 then this returns None.
UTF-16 vs UTF-8
JavaScript strings in general are encoded as UTF-16, but Rust strings
are encoded as UTF-8. This can cause the Rust string to look a bit
different than the JS string sometimes. For more details see the
documentation about the str type which contains a few
caveats about the encodings.
Sourcepub fn as_bool(&self) -> Option<bool>
pub fn as_bool(&self) -> Option<bool>
Returns the bool value of this JS value if it’s an instance of a
boolean.
If this JS value is not an instance of a boolean then this returns
None.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Tests whether this JS value is undefined
Sourcepub fn is_null_or_undefined(&self) -> bool
pub fn is_null_or_undefined(&self) -> bool
Tests whether this JS value is null or undefined
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Tests whether the type of this JS value is function.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Applies the binary in JS operator on the two JsValues.
Sourcepub fn loose_eq(&self, other: &JsValue) -> bool
pub fn loose_eq(&self, other: &JsValue) -> bool
Compare two JsValues for equality, using the == operator in JS.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Applies the binary >>> JS operator on the two JsValues.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Applies the binary / JS operator on two JsValues, catching and returning any RangeError thrown.
Sourcepub fn pow(&self, rhs: &JsValue) -> JsValue
pub fn pow(&self, rhs: &JsValue) -> JsValue
Applies the binary ** JS operator on the two JsValues.
Sourcepub fn lt(&self, other: &JsValue) -> bool
pub fn lt(&self, other: &JsValue) -> bool
Applies the binary < JS operator on the two JsValues.
Sourcepub fn le(&self, other: &JsValue) -> bool
pub fn le(&self, other: &JsValue) -> bool
Applies the binary <= JS operator on the two JsValues.
Sourcepub fn ge(&self, other: &JsValue) -> bool
pub fn ge(&self, other: &JsValue) -> bool
Applies the binary >= JS operator on the two JsValues.
Sourcepub fn gt(&self, other: &JsValue) -> bool
pub fn gt(&self, other: &JsValue) -> bool
Applies the binary > JS operator on the two JsValues.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Applies the unary + JS operator on a JsValue. Can throw.